@@ -6,6 +6,7 @@ import os, time
 import json
 import threading
 import logging
+import platform
 
 def get_terminal_size():
     '''return dimensions of current terminal session'''
@@ -266,7 +267,7 @@ class RectManager:
 
         """)
 
-        lib_path = lib_path = __file__[0:__file__.rfind("/") + 1] + "libapres_" + platform.machine() + ".so"
+        lib_path = __file__[0:__file__.rfind("/") + 1] + "libwrecked_manylinux2014_" + platform.machine() + ".so"
         self.lib = ffi.dlopen(lib_path)
 
         self.rectmanager = self.lib.init()
